/* Implementation of class Arena.
 *
 * Copyright (c) 2003 Ole Laursen.
 *
 * This program is free software; you can redistribute it and/or 
 * modify it under the terms of the GNU General Public License as 
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 * USA.
 */

#include <cassert>
#include <cstdlib>

#include "arena.hpp"

#include "obstacles.hpp"
#include "thing.hpp"

Arena *Arena::current_instance = 0;

Arena::Arena(Vector<int> d)
  : dim(d.x + 2, d.y + 2), tiles(dim.x * dim.y)
{
  assert(current_instance == 0);
  current_instance = this;
}

Arena::~Arena()
{
  current_instance = 0;
}

Arena &Arena::instance()
{
  assert(current_instance != 0);

  return *current_instance;
}

Thing *Arena::occupier(Vector<int> pos)
{
  assert(pos.x >= 0 && pos.y >= 0 && pos.x < dim.x && pos.y < dim.y);
  
  return tiles[pos.y * dim.x + pos.x];
}

void Arena::occupy(Vector<int> pos, Thing *thing)
{
  assert(pos.x >= 0 && pos.y >= 0 && pos.x < dim.x && pos.y < dim.y);
  
  tiles[pos.y * dim.x + pos.x] = thing;
}

Vector<int> Arena::get_dim()
{
  return dim;
}

Vector<int> Arena::random_tile()
{
  Vector<int> t;

  do {
    t.x = std::rand() % (dim.x - 2) + 1;
    t.y = std::rand() % (dim.y - 2) + 1;
  } while (occupier(t) != 0);

  return t;
}

