/* Implementation of obstacles classes.
 *
 * Copyright (c) 2003 Ole Laursen.
 *
 * This program is free software; you can redistribute it and/or 
 * modify it under the terms of the GNU General Public License as 
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 * USA.
 */

#include "obstacles.hpp"

#include "image-cache.hpp"
#include "main-window.hpp"
#include "graphic.hpp"
#include "arena.hpp"

#include <iostream>

Block::Block()
  : Thing(new Graphic(MainWindow::instance().get_block_layer()))
{
  get_graphic().set_pixbuf(ImageCache::instance().get("block.png").get());
}

void Block::move_block_to(Vector<int> pos)
{
  Vector<double> delta(pos.x * Arena::tile_width,
		       pos.y * Arena::tile_height);
  delta -= get_graphic().get_pos();

  occupy_tile(pos);

  for (std::list<Graphic *>::iterator i = cargo.begin(), e = cargo.end();
       i != e; ++i)
    (*i)->move(delta);
}

void Block::add_cargo(Graphic *graphic)
{
  cargo.push_back(graphic);
}

void Block::remove_cargo(Graphic *graphic)
{
  cargo.remove(graphic);
}


Wall::Wall()
  : Thing(new Graphic(MainWindow::instance().get_block_layer()))
{
  get_graphic().set_pixbuf(ImageCache::instance().get("wall.png").get());
}

